@@ -4,7 +4,7 @@ use v5.18;  # minimum for Object::Pad
 
 package Weather::GHCN::Fetch;
 
-our $VERSION = 'v0.0.002';
+our $VERSION = 'v0.0.003';
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ Weather::GHCN::Fetch - Access the NOAA GHCN Global Historical Climatology Networ
 
 =head1 VERSION
 
-version v0.0.002
+version v0.0.003
 
 =head1 DESCRIPTION
 
@@ -153,9 +153,9 @@ B<Find the 5-day heatwaves at the JFK airport station:>
 
 C<ghcn_fetch id -cou US -st NY -location "New York JFK" | ghcn_extremes>
 
-B<Find the 3-day coldwaves at the JFK airport station:>
+B<Find the 3-day coldwaves (<= 15C) at the JFK airport station:>
 
-C<ghcn_fetch id -cou US -st NY -location "New York JFK" | ghcn_extremes -cold -ndays 3>
+C<ghcn_fetch id -cou US -st NY -location "New York JFK" | ghcn_extremes -cold -ndays 3 -limit -15>
 
 B<For each year between 1900 and 1950, count the number of active weather stations in NY state:>
 
